A library for simplifying using the conrod 2D GUI library with nannou.
Re-exports
pub extern crate conrod_core;pub extern crate conrod_wgpu;pub extern crate conrod_winit;
Modules
- color
- A library providing simple
ColorandGradienttypes along with useful transformations and presets. - cursor
- Contains an extendable enum of supported mouse cursor types.
- event
- Contains all types used to describe the input events that
Widgets may handle. - graph
- Conrod uses a directed acyclic graph to manage both storing widgets and describing their relationships.
- image
- A type used to manage a user’s image data and map them to
Imagewidgets: - input
- This module contains all the logic for handling input events and providing them to widgets.
- position
- Items related to 2D positioning, used throughout conrod.
- prelude
- Simplify inclusion of common traits with a
nannou::ui::preludemodule. - scroll
- Scroll related types and logic.
- text
- Text layout logic.
- theme
- Types a functionality for handling Canvas and Widget theming.
- utils
- Various utility functions used throughout Conrod.
- widget
- Widgets are the core building blocks for every conrod user interface.
Macros
- widget_
ids - A macro used to generate a struct with a field for each unique identifier given.
Each field can then be used to generate unique
widget::Ids.
Structs
- Builder
- A type used for building a new
Ui. - Range
- Some start and end position along a single axis.
- Rect
- Defines a Rectangle’s bounds across the x and y axes.
- Theme
- A serializable collection of canvas and widget styling defaults.
- Ui
- A handle to the
Uifor a specific window. - UiCell
- A wrapper around the
Uithat restricts the user from mutating theUiin certain ways while in the scope of theUi::set_widgetsfunction and withinWidgets’updatemethods. Using theUiCell, users may access theUiimmutably (viaDeref) however they wish, however they may only mutate theUivia the&mut selfmethods provided by theUiCell.
Enums
- Bordering
- To be used as a parameter for defining the aesthetic of the widget border.
- Build
Error - Failed to build the
Ui. - Color
- Color supporting RGB and HSL variants.
- Draw
ToFrame Error - An error that might occur while drawing to a
Frame. - Input
- The event type that is used by conrod to track inputs from the world. Events yielded by polling
window backends should be converted to this type. This can be thought of as the event type
which is supplied by the window backend to drive the state of the
Uiforward. - RawWindow
Event - Describes an event from a
Window.
Traits
- Borderable
- Widgets that may display a border.
- Colorable
- Types that can be colored.
- Labelable
- Widgets that may display some label.
- Positionable
- Widgets that are positionable.
- Sizeable
- Widgets that support different dimensions.
- Widget
- A trait to be implemented by all Widget types.
Functions
- builder
- Begin building a new
Ui. - encode_
render_ pass - Encode commands for drawing the given primitives.
- image_
from_ texture - Convert the texture into an image compatible with the UI’s image map.
- winit_
window_ event_ to_ input - Convert the given window event to a UI Input.
Type Aliases
- Dimensions
- General use 2D spatial dimensions.
- Font
Size - Font size used throughout Conrod.
- Image
Map - A map from
image::Ids to their associatedTexture2d. - Point
- General use 2D spatial point.
- Scalar
- An alias over the Scalar type used throughout Conrod.